@@ -426,7 +426,7 @@ process_events_component_to_server (CalBackendWCAP *wcap, ECalComponent *comp, g
 	e_cal_component_abort_sequence (comp);
 }
 
-static ECalBackendSyncStatus
+ECalBackendSyncStatus
 cal_backend_wcap_events_update_objects (ECalBackendSync *backend, EDataCal *cal,
 				 const char *calobj, CalObjModType mod, char **old_object)
 {
@@ -452,10 +452,24 @@ cal_backend_wcap_events_update_objects (ECalBackendSync *backend, EDataCal *cal,
 	kind = icalcomponent_isa (toplevel_comp);
 	if (kind == ICAL_VEVENT_COMPONENT) {
 		icalcomponent *icalcomp;
+		icalproperty *prop;
 	
 		/* Create a temporary toplevel component and put the VEVENT
 		   in it, to simplify the code below. */
 		icalcomp = toplevel_comp;
+		prop = icalcomponent_get_first_property (icalcomp, ICAL_X_PROPERTY);
+		while (prop) {
+			const char *x_name;
+
+			x_name = icalproperty_get_x_name (prop);
+
+			if (!strcmp (x_name, "X-NSCP-GSE-COMPONENT-STATE")) {
+				icalcomponent_remove_property (icalcomp, prop);
+				break;			
+			}
+
+			prop = icalcomponent_get_next_property (icalcomp, ICAL_X_PROPERTY);
+		}
 		toplevel_comp = e_cal_util_new_top_level ();
 		icalcomponent_add_component (toplevel_comp, icalcomp);
 	} else if (kind != ICAL_VCALENDAR_COMPONENT) {
@@ -544,6 +558,8 @@ cal_backend_wcap_events_update_objects (ECalBackendSync *backend, EDataCal *cal,
 
 	if (hasImport || relativeAlarm)
 		cal_backend_wcap_poll_cb (wcap);
+	else
+		cal_backend_wcap_write_cache (wcap);
 
 	return result;
 }
@@ -628,7 +644,7 @@ cal_backend_wcap_events_remove_object (ECalBackendSync *backend, EDataCal *cal,
 		return cal_backend_wcap_result_from_error (error_code);
 	}
 
-	cal_backend_wcap_remove_component (wcap, uid, mod);
+	cal_backend_wcap_remove_component (wcap, uid, mod, old_object);
 	g_free (calobj);
 
 	cal_backend_wcap_write_cache (wcap);
