@@ -39,6 +39,8 @@ struct _CalBackendWCAPEventsClass {
 };
 
 GType cal_backend_wcap_events_get_type (void); 
+ECalBackendSyncStatus cal_backend_wcap_events_update_objects (ECalBackendSync *backend,
+							EDataCal *cal, const char *calobj, CalObjModType mod, char **old_object);
 
 G_END_DECLS
 
