@@ -730,6 +730,7 @@ process_component_from_server (CalBackendWCAP *wcap, ECalComponent *comp)
 		dt_start.tzid = g_strdup (icaltimezone_get_tzid (priv->default_zone));
 		e_cal_component_set_dtstart (comp, &dt_start);
 		if (!dt_end.value) {
+			dt_start.value->day = dt_start.value->day + 1;
 			e_cal_component_set_dtend (comp, &dt_start);
 		} else if (dt_end.value && dt_end.value->is_date) {
 			g_free ((char*)dt_end.tzid);
@@ -2247,7 +2248,7 @@ struct cbw_data {
 };
 
 static void
-e_cal_backend_wcap_compute_changes_foreach_key (const char *key, gpointer data)
+e_cal_backend_wcap_compute_changes_foreach_key (const char *key, gpointer value, gpointer data)
 {
 	struct cbw_data *cbwdata = data;
 	ECalComponent *comp = NULL;
@@ -2263,13 +2264,16 @@ e_cal_backend_wcap_compute_changes_foreach_key (const char *key, gpointer data)
 			e_cal_component_set_new_vtype (comp, E_CAL_COMPONENT_TODO);
 		else if (cbwdata->kind == ICAL_VEVENT_COMPONENT)
 			e_cal_component_set_new_vtype (comp, E_CAL_COMPONENT_EVENT);
-		else
+		else {
+			g_object_unref (comp);
 			return;
+		}
 		
 		e_cal_component_set_uid (comp, key);
 		cbwdata->deletes = g_list_prepend (cbwdata->deletes, e_cal_component_get_as_string (comp));
 
 		e_xmlhash_remove (cbwdata->ehash, key);
+		g_object_unref (comp);
 	}
 }
 
@@ -2302,11 +2306,11 @@ cal_backend_wcap_get_changes (ECalBackendSync *backend, EDataCal *cal, const cha
 	if (!account)
 		return GNOME_Evolution_Calendar_ObjectNotFound;
 	
-	if (kind ==  E_CAL_COMPONENT_EVENT)
+	if (kind ==  ICAL_VEVENT_COMPONENT)
 		dirname = g_strdup_printf ("%s/sunone/%s@%s/Calendar", evolution_dir,
 					   sunone_account_get_user (account),
 					   sunone_account_get_server (account));
-	else if (kind == E_CAL_COMPONENT_TODO)
+	else if (kind == ICAL_VTODO_COMPONENT)
 		dirname = g_strdup_printf ("%s/sunone/%s@%s/Tasks", evolution_dir,
 					   sunone_account_get_user (account),
 					   sunone_account_get_server (account));
@@ -2334,7 +2338,7 @@ cal_backend_wcap_get_changes (ECalBackendSync *backend, EDataCal *cal, const cha
 	data.ehash = xmlhash;
 	data.adds = NULL;
 	data.modifies = NULL;
-	if (kind == E_CAL_COMPONENT_EVENT || kind == E_CAL_COMPONENT_TODO)
+	if (kind == ICAL_VEVENT_COMPONENT || kind == ICAL_VTODO_COMPONENT)
 		g_hash_table_foreach (priv->objects, check_change_type, &data);
 	else
 		return GNOME_Evolution_Calendar_OtherError;
