@@ -332,13 +332,18 @@ sunone_folder_tree_connect (SunOneFolderTree *tree, SunOneAccount *account,
 
 	g_return_if_fail (SUNONE_IS_FOLDER_TREE (tree));
 
+	sunone_account_set_connecting (account, TRUE);
 	cnc = sunone_account_get_connection (account);
-	if (!cnc)
+	if (!cnc) {
+		sunone_account_set_connecting (account, FALSE);
 		return;
+	}
 
 	prefs = sunone_connection_get_preferences (cnc);
-	if (!prefs)
+	if (!prefs) {
+		sunone_account_set_connecting (account, FALSE);
 		return;
+	}
 
 	/* add tree items to sunone folder tree */
 	add_folder_tree (tree, account, iter, prefs);
@@ -346,6 +351,7 @@ sunone_folder_tree_connect (SunOneFolderTree *tree, SunOneAccount *account,
 	add_sources (account, prefs);
 	
 	sunone_connection_free_preferences (prefs);
+	sunone_account_set_connecting (account, FALSE);
 }
 
 static void
@@ -360,6 +366,8 @@ remove_calendar (SunOneFolderTree *tree, const char *full_name)
 
 	g_return_if_fail (SUNONE_IS_FOLDER_TREE (tree));
 
+	if (!full_hash)
+		return;
 	uri_row = g_hash_table_lookup (full_hash, full_name);
 	if (!uri_row)
 		return;
